@@ -3,9 +3,9 @@
 ## Author: Brice Ozenne
 ## Created: jun 27 2019 (10:43) 
 ## Version: 
-## Last-Updated: okt 30 2020 (10:38) 
-##           By: Brice Ozenne
-##     Update #: 890
+## Last-Updated: Sep  6 2023 (09:53) 
+##           By: Thomas Alexander Gerds
+##     Update #: 935
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -84,7 +84,7 @@ ATE_TI <- function(object.event,
     ## ** compute event indicators
     if(attr(estimator,"IPTW")){
         ## *** indicator for the outcome of interest stopped at time tau
-        if(inherits(object.event,"glm")){
+        if(inherits(object.event,"glm") || (is.null(object.event) && is.null(object.censor))){
             time.before.tau <- cbind(mydata[[eventVar.status]])
         }else{
             time.before.tau <- sapply(times, function(tau){mydata[[eventVar.time]] <= tau})
@@ -192,20 +192,13 @@ ATE_TI <- function(object.event,
                                                )
                 }
                 if(attr(estimator,"export.AIPTW")){
-                    if(inherits(object.event,"wglm") && attr(estimator,"IPCW")){
-                        attr(factor,"factor") <- c(attr(factor,"factor"),
-                                                   list(AIPTW = 1-colMultiply_cpp(iW.IPCW,iW.IPTW[ls.index.strata[[iC]],iC]))
-                                                   )
-                    }else{
-                        attr(factor,"factor") <- c(attr(factor,"factor"),
-                                                   list(AIPTW = cbind(1-iW.IPTW[ls.index.strata[[iC]],iC]))
-                                                   )
-                    }
+                    attr(factor,"factor") <- c(attr(factor,"factor"),
+                                               list(AIPTW = cbind(1-iW.IPTW[ls.index.strata[[iC]],iC]))
+                                               )
                 }
             }else{
                 factor <- FALSE
             }
-
             outRisk <- predictRisk(object.event, newdata = data.i, times = times,
                                    average.iid = factor, cause = cause,
                                    product.limit = product.limit)
@@ -289,19 +282,24 @@ ATE_TI <- function(object.event,
             }
         }
         if(attr(estimator,"export.IPTW")){
+
             if(attr(estimator,"IPCW")){
                 iIID.ate <- colMultiply_cpp(iW.IPCW * Y.tau, scale = iW.IPTW[,iC])
             }else{
                 iIID.ate <- colMultiply_cpp(Y.tau, scale = iW.IPTW[,iC])
             }
             iATE <- colSums(iIID.ate)/n.obs
-            out$meanRisk[list("IPTW",contrasts[iC]), c("estimate") := iATE, on = c("estimator","treatment")]
+            if(attr(estimator,"monotone")){ ## ensure monotonicity over time (not accounted for in the standard error)
+                out$meanRisk[list("IPTW",contrasts[iC]), c("estimate") := .monotonize(iATE), on = c("estimator","treatment")]
+            }else{
+                out$meanRisk[list("IPTW",contrasts[iC]), c("estimate") := iATE, on = c("estimator","treatment")]
+            }
             out$store$iid.IPTW[[iC]][data.index,] <- out$store$iid.IPTW[[iC]][data.index,]  + rowCenter_cpp(iIID.ate, center = iATE)/n.obs
         }
         if(attr(estimator,"export.AIPTW")){
             if(attr(estimator,"IPCW")){
                 if(inherits(object.event,"wglm")){
-                    iIID.ate <- F1.ctf.tau[[iC]] + colMultiply_cpp(iW.IPCW * (Y.tau - F1.ctf.tau[[iC]]), scale = iW.IPTW[,iC])
+                    iIID.ate <- F1.ctf.tau[[iC]] + colMultiply_cpp(iW.IPCW * Y.tau - F1.ctf.tau[[iC]], scale = iW.IPTW[,iC])
                 }else{
                     iIID.ate <- F1.ctf.tau[[iC]] + colMultiply_cpp(iW.IPCW * Y.tau - F1.ctf.tau[[iC]] + augTerm, scale = iW.IPTW[,iC])
                 }
@@ -309,7 +307,11 @@ ATE_TI <- function(object.event,
                 iIID.ate <- F1.ctf.tau[[iC]] + colMultiply_cpp(Y.tau - F1.ctf.tau[[iC]], scale = iW.IPTW[,iC])
             }
             iATE <- colSums(iIID.ate)/n.obs
-            out$meanRisk[list("AIPTW",contrasts[iC]), c("estimate") := iATE, on = c("estimator","treatment")]
+            if(attr(estimator,"monotone")){ ## ensure monotonicity over time (not accounted for in the standard error)
+                out$meanRisk[list("AIPTW",contrasts[iC]), c("estimate") := .monotonize(iATE), on = c("estimator","treatment")]
+            }else{
+                out$meanRisk[list("AIPTW",contrasts[iC]), c("estimate") := iATE, on = c("estimator","treatment")]
+            }
             out$store$iid.AIPTW[[iC]][data.index,] <- out$store$iid.AIPTW[[iC]][data.index,] + rowCenter_cpp(iIID.ate, center = iATE)/n.obs
         }
     }
@@ -379,7 +381,7 @@ ATE_TD <- function(object.event,
     response <- eval(formula[[2]],envir=mydata)
     time <- response[,"time"]
     entry <- response[,"entry"]
-    if(class(object.event)[[1]]=="coxph"){
+    if(inherits(x=object.event,what="coxph")){
         riskhandler <- "predictRisk.coxphTD"
     }else{
         riskhandler <- "predictRisk.CSCTD"
@@ -419,9 +421,9 @@ ATE_TD <- function(object.event,
 ## * ATE_COMPARISONS: compute average risk for time dependent covariates (using G-formula)
 ATE_COMPARISONS <- function(data, TD, allContrasts){
     ## duplicate
-    dataA <- copy(data)
+    dataA <- data.table::copy(data)
     setnames(dataA, old = c("treatment","estimate"), new = c("A","estimate.A"))
-    dataB <- copy(data)
+    dataB <- data.table::copy(data)
     setnames(dataB, old = c("treatment","estimate"), new = c("B","estimate.B"))
 
     ## perform all pairwise combinations
@@ -441,6 +443,21 @@ ATE_COMPARISONS <- function(data, TD, allContrasts){
     ## export
     return(out)
 }
+## * .monotonize: enforce monotone constrain over time
+## .monotonize(c(0.3708385, 0.4035446, 0.4346159, 0.4591131, 0.4844758, 0.4894976 ))
+## .monotonize(c(0.3708385, 0.4035446, 0.4346159, 0.4591131, 0.4844758, 0.47 ))
+## .monotonize(c(0.3708385, 0.37, 0.4346159, 0.4591131, 0.4844758, 0.4894976 ))
+## .monotonize(c(0.3708385, 0.4035446, 0.40, 0.4591131, 0.4844758, 0.4894976 ))
+## .monotonize(c(0.4, 0.35, 0.38, 0.37, 0.4844758, 0.4894976 ))
+.monotonize <- function(x){
+    if(length(x)==1){return(x)}
 
+    p <- length(x)
+    A <- matrix(0,p,p)
+    A[lower.tri(A, diag = TRUE)] <- 1
+
+    fit <- nnls::nnls(A = A, b = x)$fitted
+    return(fit)
+}
 ######################################################################
 ### ate-pointEstimate.R ends here
