@@ -3,9 +3,9 @@
 ## author: Brice Ozenne
 ## created: feb 27 2017 (10:47) 
 ## Version: 
-## last-updated: sep 24 2020 (14:30) 
-##           By: Brice Ozenne
-##     Update #: 103
+## last-updated: Sep  6 2023 (09:53) 
+##           By: Thomas Alexander Gerds
+##     Update #: 110
 #----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -81,7 +81,7 @@ autoplot.predictCSC <- function(object,
                                 ...){
   
     ## initialize and check
-    group.by <- match.arg(group.by, c("row","covariates","strata"))
+    group.by <- match.arg(group.by, c("row","covariates","strata", names(object$newdata)))
   
     if(group.by[[1]] == "covariates" && ("newdata" %in% names(object) == FALSE)){
         stop("argument \'group.by\' cannot be \"covariates\" when newdata is missing in the object \n",
@@ -113,7 +113,7 @@ autoplot.predictCSC <- function(object,
     
 
     ## display
-    newdata <- copy(object$newdata)
+    newdata <- data.table::copy(object$newdata)
     if(!is.null(newdata) && reduce.data[[1]]){
         test <- unlist(newdata[,lapply(.SD, function(col){length(unique(col))==1})])
         if(any(test)){
