@@ -3,9 +3,9 @@
 ## Author: Thomas Alexander Gerds
 ## Created: Feb 27 2022 (09:12) 
 ## Version: 
-## Last-Updated: Sep 16 2022 (19:44) 
+## Last-Updated: Sep  6 2023 (09:54) 
 ##           By: Thomas Alexander Gerds
-##     Update #: 25
+##     Update #: 39
 #----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -35,7 +35,7 @@ getPerformanceData <- function(testdata,
     ID=model = risk = NULL
     # inherit everything else from parent frame: object, nullobject, NF, NT, times, cause, response.type, etc.
     Brier=IPA=IBS=NULL
-    looping <- !is.null(traindata)
+    looping <- length(traindata)>0
     N <- as.numeric(NROW(testdata))
     # split data vertically into response and predictors X
     response <- testdata[,1:response.dim,with=FALSE]
@@ -44,7 +44,7 @@ getPerformanceData <- function(testdata,
     X <- testdata[,-c(1:response.dim),with=FALSE]
     ## restore sanity
     setnames(X,sub("^protectedName.","",names(X)))
-    if (debug) message("extracted test set and prepared output object")
+    if (debug) message("\nExtracted test set and prepared output object")
     # }}}
     # {{{ collect pred as long format data.table
     args <- switch(response.type,"binary"={list(newdata=X)},
@@ -58,7 +58,7 @@ getPerformanceData <- function(testdata,
         trainX <- traindata[,-c(1:response.dim),with=FALSE]
         ## restore sanity
         setnames(trainX,sub("^protectedName.","",names(trainX)))
-        ## trainX <- copy(traindata)
+        ## trainX <- data.table::copy(traindata)
         trainX[,ID:=NULL]
     }
     pred <- data.table::rbindlist(lapply(levs, function(f){
@@ -86,7 +86,6 @@ getPerformanceData <- function(testdata,
         }else{
             # predictions given as model which needs training in crossvalidation loops
             if (looping){
-                # browser(skipCalls = 1)
                 set.seed(trainseed)
                 if (f==0) model.f=nullobject[[1]] else model.f=object[[f]]
                 model.f$call$data <- trainX
@@ -118,6 +117,8 @@ getPerformanceData <- function(testdata,
         }
     }))
     if (any(is.na(pred$risk))) {
+        ## browser(skipCalls = 1)
+        message("Table of missing values in predicted risks:")
         pred[,model:=factor(model,levels=levs,labels)]
         if (response.type[1] == "binary"){
             print(pred[is.na(risk),data.table::data.table("sum(NA)" = .N),by = list(model)])
@@ -126,7 +127,7 @@ getPerformanceData <- function(testdata,
             print(pred[is.na(risk),data.table::data.table("sum(NA)" = .N),by = list(model,times)])
         stop("Missing values in predicted risk detected.")
     }
-    if (debug) message("trained the model(s) and extracted the predictions")
+    if (debug) message("\nTrained the model(s) and extracted the predictions")
     # }}}
     # {{{ merge with Weights (IPCW inner loop)
     if (response.type %in% c("survival","competing.risks")){
