@@ -3,9 +3,9 @@
 ## author: Thomas Alexander Gerds
 ## created: Jun  6 2016 (09:02)
 ## Version:
-## last-updated: Jul  7 2022 (17:33) 
+## last-updated: Sep  7 2023 (09:06) 
 ##           By: Thomas Alexander Gerds
-##     Update #: 450
+##     Update #: 526
 #----------------------------------------------------------------------
 ##
 ### Commentary:
@@ -51,6 +51,7 @@
 #' @param product.limit If \code{TRUE} the survival is computed using the product limit estimator.
 #' Otherwise the exponential approximation is used (i.e. exp(-cumulative hazard)).
 #' @param landmark The starting time for the computation of the cumulative risk.
+#' @param truncate If \code{TRUE} truncates the predicted risks to be in the range [0, 1]. For now only implemented for the Cause Specific Cox model. 
 #' @param \dots Additional arguments that are passed on to the current method.
 #'
 #' @return For binary outcome a vector with predicted risks. For survival outcome with and without
@@ -87,88 +88,44 @@
 #' nd <- sampleData(80,outcome="binary")
 #' fit <- lrm(Y~X1+X8,data=d)
 #' predictRisk(fit,newdata=nd)
-#'\dontrun{
-#' library(SuperLearner)
-#' set.seed(1)
-#' sl = SuperLearner(Y = d$Y, X = d[,-1], family = binomial(),
-#'       SL.library = c("SL.mean", "SL.glmnet", "SL.randomForest"))
-#'}
 #'
 #' ## survival outcome
-#' # generate survival data
-#' library(prodlim)
-#' set.seed(100)
-#' d <- sampleData(100,outcome="survival")
-#' d[,X1:=as.numeric(as.character(X1))]
-#' d[,X2:=as.numeric(as.character(X2))]
-#' # then fit a Cox model
-#' library(rms)
-#' cphmodel <- cph(Surv(time,event)~X1+X2,data=d,surv=TRUE,x=TRUE,y=TRUE)
-#' # or via survival
-#' library(survival)
-#' coxphmodel <- coxph(Surv(time,event)~X1+X2,data=d,x=TRUE,y=TRUE)
-#'
-#' # Extract predicted survival probabilities
-#' # at selected time-points:
-#' ttt <- quantile(d$time)
-#' # for selected predictor values:
-#' ndat <- data.frame(X1=c(0.25,0.25,-0.05,0.05),X2=c(0,1,0,1))
-#' # as follows
-#' predictRisk(cphmodel,newdata=ndat,times=ttt)
-#' predictRisk(coxphmodel,newdata=ndat,times=ttt)
-#'
-#' # stratified cox model
-#' sfit <- coxph(Surv(time,event)~strata(X1)+X2,data=d,x=TRUE,y=TRUE)
-#' predictRisk(sfit,newdata=d[1:3,],times=c(1,3,5,10))
-#'
 #' ## simulate learning and validation data
 #' set.seed(10)
-#' learndat <- sampleData(100,outcome="survival")
-#' valdat <- sampleData(100,outcome="survival")
+#' learndat <- sampleData(80,outcome="survival")
+#' valdat <- sampleData(10,outcome="survival")
 #' ## use the learning data to fit a Cox model
 #' library(survival)
-#' fitCox <- coxph(Surv(time,event)~X1+X2,data=learndat,x=TRUE,y=TRUE)
+#' fitCox <- coxph(Surv(time,event)~X8+X9,data=learndat,x=TRUE,y=TRUE)
 #' ## suppose we want to predict the survival probabilities for all subjects
-#' ## in the validation data at the following time points:
-#' ## 0, 12, 24, 36, 48, 60
-#' psurv <- predictRisk(fitCox,newdata=valdat,times=seq(0,60,12))
-#' ## This is a matrix with event probabilities (1-survival)
+#' ## in the validation data at the time points 0,5,10:
+#' psurv <- predictRisk(fitCox,newdata=valdat,times=c(0,5,10))
+#' ## This is a matrix with event probabilities,
 #' ## one column for each of the 5 time points
 #' ## one row for each validation set individual
-#'
-#' if (require("randomForestSRC",quietly=TRUE)){
-#' # Do the same for a randomSurvivalForest model
-#' library(randomForestSRC)
-#' rsfmodel <- rfsrc(Surv(time,event)~X1+X2,data=learndat)
-#' prsfsurv=predictRisk(rsfmodel,newdata=valdat,times=seq(0,60,12))
-#' plot(psurv,prsfsurv)
-#' }
-#' ## Cox with ridge option
-#' f1 <- coxph(Surv(time,event)~X1+X2,data=learndat,x=TRUE,y=TRUE)
-#' f2 <- coxph(Surv(time,event)~ridge(X1)+ridge(X2),data=learndat,x=TRUE,y=TRUE)
+#' ## where event probability = 1 - survival probability
 #' \dontrun{
-#' plot(predictRisk(f1,newdata=valdat,times=10),
-#'      riskRegression:::predictRisk.coxph(f2,newdata=valdat,times=10),
-#'      xlim=c(0,1),
-#'      ylim=c(0,1),
-#'      xlab="Unpenalized predicted survival chance at 10",
-#'      ylab="Ridge predicted survival chance at 10")
-#'}
+#' if (require("randomForestSRC",quietly=TRUE)){
+#' # Do the same with a randomSurvivalForest model
+#' library(randomForestSRC)
+#' rsfmodel <- rfsrc(Surv(time,event)~X1+X2,data=learndat,ntree=5)
+#' prsfsurv=predictRisk(rsfmodel,newdata=valdat,times=seq(0,5,10))
+#' }
+#' }
 #'
 #' ## competing risks
-#'
 #' library(survival)
 #' library(riskRegression)
 #' library(prodlim)
-#' train <- prodlim::SimCompRisk(100)
-#' test <- prodlim::SimCompRisk(10)
-#' cox.fit  <- CSC(Hist(time,cause)~X1+X2,data=train)
-#' predictRisk(cox.fit,newdata=test,times=seq(1:10),cause=1)
-#'
-#' ## with strata
-#' cox.fit2  <- CSC(list(Hist(time,cause)~strata(X1)+X2,Hist(time,cause)~X1+X2),data=train)
-#' predictRisk(cox.fit2,newdata=test,times=seq(1:10),cause=1)
+#' train <- sampleData(50)
+#' test <- sampleData(10)
+#' cox.fit  <- CSC(Hist(time,event)~X7+X8,data=train)
+#' predictRisk(cox.fit,newdata=test,times=c(3,8),cause=1)
 #'
+#' ## with strata and cause 2
+#' cox.fit2  <- CSC(list(Hist(time,event)~strata(X1)+X2,Hist(time,cause)~X1+X2),data=train)
+#' predictRisk(cox.fit2,newdata=test,times=c(3,5),cause=2)
+#' 
 #' @export
 predictRisk <- function(object,newdata,...){
     UseMethod("predictRisk",object)
@@ -179,7 +136,7 @@ predictRisk <- function(object,newdata,...){
 #' @rdname predictRisk
 #' @method predictRisk default
 predictRisk.default <- function(object,newdata,times,cause,...){
-    stop(paste0("No method available for evaluating predicted probabilities from objects in class: ",class(object),". But, you can write it yourself or ask the package manager."),call.=FALSE)
+    stop(paste0("No method available for evaluating predicted probabilities from objects in class: ",paste0(class(object),collapse = ", "),". But, you can write it yourself or ask the package manager."),call.=FALSE)
 }
 
 ## * predictRisk.double
@@ -321,7 +278,11 @@ predictRisk.glm <- function(object, newdata, iid = FALSE, average.iid = FALSE,..
         stop("Currently only the binomial family is implemented for predicting a status from a glm object.")
     }
 }
+
 ## * predictRisk.multinom
+##' @export
+##' @rdname predictRisk
+##' @method predictRisk multinom
 predictRisk.multinom <- function(object, newdata, iid = FALSE, average.iid = FALSE, cause = NULL, ...){
     n.obs <- NROW(newdata)
     n.class <- length(object$lev)
@@ -533,36 +494,17 @@ predictRisk.matrix <- function(object,newdata,times,cause,...){
 ##' @rdname predictRisk
 ##' @method predictRisk aalen
 predictRisk.aalen <- function(object,newdata,times,...){
-    ## require(timereg)
-    stop("FIXME")
-    time.coef <- data.frame(object$cum)
-    ntime <- nrow(time.coef)
-    objecttime <- time.coef[,1,drop=TRUE]
-    ntimevars <- ncol(time.coef)-2
-    covanames <- names(time.coef)[-(1:2)]
-    notfound <- match(covanames,names(newdata),nomatch=0)==0
-    if (any(notfound))
-        stop("\nThe following predictor variables:\n\n",
-             paste(covanames[notfound],collapse=","),
-             "\n\nwere not found in newdata, which only provides the following variables:\n\n",
-             paste(names(newdata),collapse=","),
-             "\n\n")
-    time.vars <- cbind(1,newdata[,names(time.coef)[-(1:2)],drop=FALSE])
-    nobs <- nrow(newdata)
-    ## hazard <- .C("survest_cox_aalen",
-                 ## timehazard=double(ntime*nobs),
-                 ## as.double(unlist(time.coef[,-1])),
-                 ## as.double(unlist(time.vars)),
-                 ## as.integer(ntimevars+1),
-                 ## as.integer(nobs),
-                 ## as.integer(ntime),PACKAGE="pec")$timehazard
-    hazard <- matrix(hazard,ncol=ntime,nrow=nobs,dimnames=list(1:nobs,paste("TP",1:ntime,sep="")))
-    surv <- pmin(exp(-hazard),1)
-    if (missing(times)) times <- sort(unique(objecttime))
-    p <- surv[,prodlim::sindex(jump.times=objecttime,eval.times=times)]
-    if (NROW(p) != NROW(newdata) || NCOL(p) != length(times))
-        stop(paste("\nPrediction matrix has wrong dimensions:\nRequested newdata x times: ",NROW(newdata)," x ",length(times),"\nProvided prediction matrix: ",NROW(p)," x ",NCOL(p),"\n\n",sep=""))
-    1-p
+  if (is.null(object$B.iid)) {
+    stop("Need resample.iid=1 when fitting the aalen model to make",
+         " predictions. Please re-fit the aalen model with resample.idd=1.")
+  }
+  
+  out <- timereg::predict.aalen(object=object,
+                                newdata=newdata,
+                                times=times,
+                                se=FALSE,
+                                ...)$S0
+  return(1 - out)
 }
 
 ## * predictRisk.cox.aalen
@@ -570,29 +512,26 @@ predictRisk.aalen <- function(object,newdata,times,...){
 ##' @rdname predictRisk
 ##' @method predictRisk cox.aalen
 predictRisk.cox.aalen <- function(object,newdata,times,...){
-    #  require(timereg)
-    ##  The time-constant effects first
-    stop("FIXME")
-    const <- c(object$gamma)
-    names(const) <- substr(dimnames(object$gamma)[[1]],6,nchar(dimnames(object$gamma)[[1]])-1)
-    constant.part <- t(newdata[,names(const)])*const
-    constant.part <- exp(colSums(constant.part))
-    ##  Then extract the time-varying effects
-    time.coef <- data.frame(object$cum)
-    ntime <- nrow(time.coef)
-    objecttime <- time.coef[,1,drop=TRUE]
-    ntimevars <- ncol(time.coef)-2
-    time.vars <- cbind(1,newdata[,names(time.coef)[-(1:2)],drop=FALSE])
-    nobs <- nrow(newdata)
-    ## time.part <- .C("survest_cox_aalen",timehazard=double(ntime*nobs),as.double(unlist(time.coef[,-1])),as.double(unlist(time.vars)),as.integer(ntimevars+1),as.integer(nobs),as.integer(ntime),PACKAGE="pec")$timehazard
-    time.part <- matrix(time.part,ncol=ntime,nrow=nobs)
-    ## dimnames=list(1:nobs,paste("TP",1:ntime,sep="")))
-    surv <- pmin(exp(-time.part*constant.part),1)
-    if (missing(times)) times <- sort(unique(objecttime))
-    p <- surv[,prodlim::sindex(objecttime,times)]
-    if (NROW(p) != NROW(newdata) || NCOL(p) != length(times))
-        stop(paste("\nPrediction matrix has wrong dimensions:\nRequested newdata x times: ",NROW(newdata)," x ",length(times),"\nProvided prediction matrix: ",NROW(p)," x ",NCOL(p),"\n\n",sep=""))
-    1-p
+    out <- timereg::predict.cox.aalen(object=object,
+                                      newdata=newdata,
+                                      times=times,
+                                      se=FALSE,
+                                      ...)$S0
+    return(1 - out)
+}
+
+
+## * predictRisk.comprisk
+##' @export
+##' @rdname predictRisk
+##' @method predictRisk comprisk
+predictRisk.comprisk <- function(object, newdata, times, ...) {
+  out <- timereg::predict.comprisk(object=object,
+                                   newdata=newdata,
+                                   times=times,
+                                   se=FALSE,
+                                   ...)$P1
+  return(out)
 }
 
 
@@ -733,22 +672,26 @@ predictRisk.CSCTD <- function(object,newdata,times,cause,landmark,...){
 ##' @rdname predictRisk
 ##' @method predictRisk coxph.penal
 predictRisk.coxph.penal <- function(object,newdata,times,...){
-  frailhistory <- object$history$'frailty(cluster)'$history
-  frailVar <- frailhistory[NROW(frailhistory),1]
-  linearPred <- predict(object,newdata=newdata,se.fit=FALSE,conf.int=FALSE)
-  basehaz <- basehaz(object)
-  bhTimes <- basehaz[,2]
-  bhValues <- basehaz[,1]
-  survPred <- do.call("rbind",lapply(1:NROW(newdata),function(i){
-    (1+frailVar*bhValues*exp(linearPred[i]))^{-1/frailVar}
-  }))
-  where <- prodlim::sindex(jump.times=bhTimes,eval.times=times)
-  p <- cbind(1,survPred)[,where+1]
-  if ((miss.time <- (length(times) - NCOL(p)))>0)
-    p <- cbind(p,matrix(rep(NA,miss.time*NROW(p)),nrow=NROW(p)))
-  if (NROW(p) != NROW(newdata) || NCOL(p) != length(times))
-      stop(paste("\nPrediction matrix has wrong dimensions:\nRequested newdata x times: ",NROW(newdata)," x ",length(times),"\nProvided prediction matrix: ",NROW(p)," x ",NCOL(p),"\n\n",sep=""))
-  1-p
+    frailhistory <- object$history$'frailty(cluster)'$history
+    if (length(frailhistory) == 0){
+        predictRisk.coxph(object,newdata,times,...)
+    }else{
+        frailVar <- frailhistory[NROW(frailhistory),1]
+        linearPred <- predict(object,newdata=newdata,se.fit=FALSE,conf.int=FALSE)
+        basehaz <- basehaz(object)
+        bhTimes <- basehaz[,2]
+        bhValues <- basehaz[,1]
+        survPred <- do.call("rbind",lapply(1:NROW(newdata),function(i){
+            (1+frailVar*bhValues*exp(linearPred[i]))^{-1/frailVar}
+        }))
+        where <- prodlim::sindex(jump.times=bhTimes,eval.times=times)
+        p <- cbind(1,survPred)[,where+1]
+        if ((miss.time <- (length(times) - NCOL(p)))>0)
+            p <- cbind(p,matrix(rep(NA,miss.time*NROW(p)),nrow=NROW(p)))
+        if (NROW(p) != NROW(newdata) || NCOL(p) != length(times))
+            stop(paste("\nPrediction matrix has wrong dimensions:\nRequested newdata x times: ",NROW(newdata)," x ",length(times),"\nProvided prediction matrix: ",NROW(p)," x ",NCOL(p),"\n\n",sep=""))
+        1-p
+    }
 }
 
 
@@ -888,6 +831,7 @@ predictRisk.psm <- function(object,newdata,times,...){
 ##' @rdname predictRisk
 ##' @method predictRisk ranger
 predictRisk.ranger <- function(object, newdata, times, cause, ...){
+    if (object$treetype == "Regression") stop("Don't know how to predict risks based on regression trees.")
     xvars <- object$forest$independent.variable.names
     newdata <- subset(newdata,select=xvars)
     if (missing(times)||is.null(times)){
@@ -905,9 +849,9 @@ predictRisk.ranger <- function(object, newdata, times, cause, ...){
             ptemp <- 1-stats::predict(object,data=newdata,...)$survival
             pos <- prodlim::sindex(jump.times=ranger::timepoints(object),eval.times=times)
             if (NROW(newdata) == 1)
-                p <- matrix(c(1,ptemp),nrow = 1)[,pos+1,drop=FALSE]
+                p <- matrix(c(0,ptemp),nrow = 1)[,pos+1,drop=FALSE]
             else
-                p <- cbind(1,ptemp)[,pos+1,drop=FALSE]
+                p <- cbind(0,ptemp)[,pos+1,drop=FALSE]
             if (NROW(p) != NROW(newdata) || NCOL(p) != length(times))
                 stop(paste("\nPrediction matrix has wrong dimensions:\nRequested newdata x times: ",NROW(newdata)," x ",length(times),"\nProvided prediction matrix: ",NROW(p)," x ",NCOL(p),"\n\n",sep=""))
             p
@@ -931,7 +875,7 @@ predictRisk.rfsrc <- function(object, newdata, times, cause, ...){
         if (object$family[[1]]=="surv") {
             ptemp <- 1-stats::predict(object,newdata=newdata,importance="none",...)$survival
             pos <- prodlim::sindex(jump.times=object$time.interest,eval.times=times)
-            p <- cbind(1,ptemp)[,pos+1,drop=FALSE]
+            p <- cbind(0,ptemp)[,pos+1,drop=FALSE]
             if (NROW(p) != NROW(newdata) || NCOL(p) != length(times))
                 stop(paste("\nPrediction matrix has wrong dimensions:\nRequested newdata x times: ",NROW(newdata)," x ",length(times),"\nProvided prediction matrix: ",NROW(p)," x ",NCOL(p),"\n\n",sep=""))
             p
@@ -1001,14 +945,13 @@ predictRisk.ARR <- function(object,newdata,times,cause,...){
 ##' @rdname predictRisk
 ##' @method predictRisk CauseSpecificCox
 predictRisk.CauseSpecificCox <- function (object, newdata, times, cause,
-                                          product.limit = TRUE, diag = FALSE, iid = FALSE, average.iid = FALSE, ...) {
+                                          product.limit = TRUE, diag = FALSE, iid = FALSE, average.iid = FALSE, truncate = FALSE, ...) {
     dots <- list(...)
     type <- dots$type
     if(is.null(type)){
         type <- "absRisk"
     }
     store.iid <- dots$store.iid
-
     outPred <- predict(object=object,
                        newdata=newdata,
                        times=times,
@@ -1021,15 +964,17 @@ predictRisk.CauseSpecificCox <- function (object, newdata, times, cause,
                        product.limit = product.limit,
                        store.iid = store.iid,
                        type = type)
-
+    
     out <- outPred[[type]]
+    if (truncate){
+      out <- apply(out, c(1, 2), function(x) max(min(x,1),0))
+    }
     if(iid){
         attr(out,"iid") <- outPred[[paste0(type,".iid")]]
     }
     if(average.iid){
         attr(out,"average.iid") <- outPred[[paste0(type,".average.iid")]]
     }
-
     return(out)
 }
 
@@ -1336,32 +1281,6 @@ predictRisk.flexsurvreg <- function(object, newdata, times, ...) {
     1 - p
 }
 
-Hal9001 <- function(formula,data,lambda,...){
-    requireNamespace("hal9001")
-    strata.num = start = status = NULL
-    EHF = prodlim::EventHistory.frame(formula,data,unspecialsDesign = TRUE,specials = NULL)
-    stopifnot(attr(EHF$event.history,"model")[[1]] == "survival")
-    # blank Cox object needed for predictions
-    data = data.frame(cbind(EHF$event.history,EHF$design))
-    bl_cph <- coxph(Surv(time,status)~1,data=data,x=1,y=1)
-    bl_obj <- coxModelFrame(bl_cph)[]
-    bl_obj[,strata.num:=0]
-    data.table::setorder(bl_obj, strata.num,stop,start,-status)
-    hal_fit <- do.call(hal9001::fit_hal,list(X = EHF$design,
-                                             Y = EHF$event.history,
-                                             family = "cox",
-                                             return_lasso = TRUE,
-                                             yolo = FALSE,
-                                             lambda = lambda,
-                                             ...))
-    out = list(fit = hal_fit,
-               surv_info = bl_obj,
-               call = match.call(),
-               terms = terms(formula))
-    class(out) = "Hal9001"
-    out
-}
-
 ##' @export
 ##' @rdname predictRisk
 ##' @method predictRisk Hal9001
@@ -1397,7 +1316,7 @@ predictRisk.Hal9001 <- function(object,
                                       cause = 1,
                                       Efron = TRUE)
     hal_Surv <- exp(-hal_pred%o%L0$cumhazard)
-    where <- sindex(jump.times=info$stop,eval.times=times)
+    where <- sindex(jump.times=unique(info$stop),eval.times=times)
     p <- cbind(0,1-hal_Surv)[,1+where]
     if (NROW(p) != NROW(newdata) || NCOL(p) != length(times)) {
         stop(paste("\nPrediction matrix has wrong dimensions:\nRequested newdata x times: ", NROW(newdata), " x ", length(times), "\nProvided prediction matrix: ", NROW(p), " x ", NCOL(p), "\n\n", sep = ""))
@@ -1405,6 +1324,100 @@ predictRisk.Hal9001 <- function(object,
     p
 }
 
+## * predictRisk.GLMnet
+##' @rdname predictRisk
+##' @method predictRisk GLMnet
+##' @export
+predictRisk.GLMnet <- function(object,newdata,times=NA,...) {
+  args <- list(...)
+  if (length(args$lambda)>0){
+    stopifnot(all(is.numeric(args$lambda)))
+    if (length(args$lambda)>1)
+      stop("You must pick a single lambda value for predictRisk!")
+    else{
+      pos.lambda <- match(args$lambda,object$lambda,nomatch = 0)
+      if (pos.lambda == 0)
+        stop("The fitted model was not fitted with the specified penalty parameter (lambda)")
+    }
+  }else{
+    pos.lambda <- 0
+  }
+  lambda=cv=NULL
+  # library(glmnet)
+  # requireNamespace(c("prodlim","glmnet"))
+  # predict.cv.glmnet <- utils::getFromNamespace("predict.cv.glmnet","glmnet")
+  # predict.glmnet <- utils::getFromNamespace("predict.glmnet","glmnet")
+  rhs <- as.formula(delete.response(object$terms))
+  if (length(info <- object$surv_info) == 0){
+    xnew <- model.matrix(rhs,data=newdata)
+    if (is.null(args$lambda) && object$cv){
+      p <- predict(object$fit,newx=xnew,type = "response", s="lambda.min")
+    }
+    else if (pos.lambda == 0 && !object$cv){
+      if (length(object$lambda) == 1){
+        p <- predict(object$fit,newx=xnew,type = "response", s=object$lambda)
+      }
+      else {
+        stop("Object fitted with multiple lambdas. You must pick one lambda for predictRisk!")
+      }
+    }
+    else {
+      p <- predict(object$fit,newx=xnew,type = "response", s=args$lambda)
+    }
+  } else {
+    # convert covariates to dummy variables
+    newdata$dummy.time=rep(1,NROW(newdata))
+    newdata$dummy.event=rep(1,NROW(newdata))
+    dummy.formula=stats::update.formula(rhs,"prodlim::Hist(dummy.time,dummy.event)~.")
+    EHF <- prodlim::EventHistory.frame(formula=dummy.formula,data=newdata,specials = NULL,unspecialsDesign=TRUE)
+    newdata$dummy.time = NULL
+    newdata$dummy.event = NULL
+    # blank Cox object obtained with riskRegression:::coxModelFrame
+    if (pos.lambda == 0 && object$cv){
+      coxnet_pred <- c(exp(predict(object$fit,newx=EHF$design,type = "link", s="lambda.min")))
+      lambda <- object$fit$lambda.min ## is needed for train_eXb
+    }
+    else if (pos.lambda == 0 && !object$cv){
+      if (length(object$lambda) == 1){
+        coxnet_pred <- c(exp(predict(object$fit,newx=EHF$design,type = "link", s=object$lambda)))
+        lambda <- object$lambda
+      }
+      else {
+        stop("Object fitted with multiple lambdas. You must pick a single value for lambda.")
+      }
+    } else {
+      if (all((pos.lambda)>0)){
+        coxnet_pred <- c(exp(predict(object$fit,newx=EHF$design,type = "link", s=args$lambda)))
+        lambda <- args$lambda
+      }
+      else {
+        stop(paste0("The fitted model was not fitted with the following penalty parameters (lambdas): ",
+                    paste0(args$lambda[pos.lambda == 0],collapse = ", ")))
+      }
+    }
+    train_eXb <- c(exp(predict(object$fit,newx=object$sorted_x_train,type = "link", s=lambda)))
+    L0 <- riskRegression::baseHaz_cpp(starttimes = info$start,
+                                      stoptimes = info$stop,
+                                      status = info$status,
+                                      eXb = train_eXb,
+                                      strata = 1,
+                                      nPatients = NROW(info$stop),
+                                      nStrata = 1,
+                                      emaxtimes = max(info$stop),
+                                      predtimes = sort(unique(info$stop)),
+                                      cause = 1,
+                                      Efron = TRUE)$cumhazard
+    ## if (any(is.na(L0))) browser()
+    coxnetSurv <- exp(-coxnet_pred%o%L0)
+    where <- sindex(jump.times=unique(info$stop),eval.times=times)
+    p <- cbind(0,1-coxnetSurv)[,1+where]
+  }
+  if (NROW(p) != NROW(newdata) || NCOL(p) != length(times)) {
+    stop(paste("\nPrediction matrix has wrong dimensions:\nRequested newdata x times: ", NROW(newdata), " x ", length(times), "\nProvided prediction matrix: ", NROW(p), " x ", NCOL(p), "\n\n", sep = ""))
+  }
+  p
+}
+
 
 ## * predictRisk.singleEventCB
 ##' @export
@@ -1450,36 +1463,36 @@ predictRisk.singleEventCB <- function(object, newdata, times, cause, ...) {
 }
 
 
-GrpSurv <- function(formula,data,...){
-    requireNamespace(c("grpreg","prodlim"))
-    EHF = prodlim::EventHistory.frame(formula,data,unspecialsDesign = TRUE,specials = NULL)
-    fit = grpreg::grpsurv(X = EHF$design,y = EHF$event.history,...)
-    fit = list(fit = fit,terms = terms(formula),call=match.call())
-    class(fit) = c("GrpSurv",class(fit))
-    fit
-}
+## GrpSurv <- function(formula,data,...){
+    ## requireNamespace(c("grpreg","prodlim"))
+    ## EHF = prodlim::EventHistory.frame(formula,data,unspecialsDesign = TRUE,specials = NULL)
+    ## fit = grpreg::grpsurv(X = EHF$design,y = EHF$event.history,...)
+    ## fit = list(fit = fit,terms = terms(formula),call=match.call())
+    ## class(fit) = c("GrpSurv",class(fit))
+    ## fit
+## }
 
-predictRisk.GrpSurv <- function(object, newdata, times, cause, ...){
-    newdata$dummy.time=rep(1,NROW(newdata))
-    newdata$dummy.event=rep(1,NROW(newdata))
-    rhs <- as.formula(delete.response(object$terms))
-    dummy.formula=stats::update.formula(rhs,"Hist(dummy.time,dummy.event)~.")
-    EHF <- prodlim::EventHistory.frame(formula=dummy.formula,
-                                       data=newdata,
-                                       specials = NULL,
-                                       unspecialsDesign=TRUE)
-    newdata$dummy.time = NULL
-    newdata$dummy.event = NULL
-    p <- predict(object$fit, EHF$design, type="survival")
-    p <- 1-sapply(p,function(f)f(times))
-    if (length(times) == 1){
-        p = cbind(p)
-    }else(p = t(p))
-    if (NROW(p) != NROW(newdata) || NCOL(p) != length(times)) {
-        stop(paste("\nPrediction matrix has wrong dimensions:\nRequested newdata x times: ", NROW(newdata), " x ", length(times), "\nProvided prediction matrix: ", NROW(p), " x ", NCOL(p), "\n\n", sep = ""))
-    }
-    p
-}
+## predictRisk.GrpSurv <- function(object, newdata, times, cause, ...){
+    ## newdata$dummy.time=rep(1,NROW(newdata))
+    ## newdata$dummy.event=rep(1,NROW(newdata))
+    ## rhs <- as.formula(delete.response(object$terms))
+    ## dummy.formula=stats::update.formula(rhs,"Hist(dummy.time,dummy.event)~.")
+    ## EHF <- prodlim::EventHistory.frame(formula=dummy.formula,
+                                       ## data=newdata,
+                                       ## specials = NULL,
+                                       ## unspecialsDesign=TRUE)
+    ## newdata$dummy.time = NULL
+    ## newdata$dummy.event = NULL
+    ## p <- predict(object$fit, EHF$design, type="survival")
+    ## p <- 1-sapply(p,function(f)f(times))
+    ## if (length(times) == 1){
+        ## p = cbind(p)
+    ## }else(p = t(p))
+    ## if (NROW(p) != NROW(newdata) || NCOL(p) != length(times)) {
+        ## stop(paste("\nPrediction matrix has wrong dimensions:\nRequested newdata x times: ", NROW(newdata), " x ", length(times), "\nProvided prediction matrix: ", NROW(p), " x ", NCOL(p), "\n\n", sep = ""))
+    ## }
+    ## p
+## }
 
 ## XgbSurv <- function(formula,data,...){
     ## requireNamespace(c("survXgboost","xgboost","prodlim"))
